==> larus_board-0.9.9.zip: larus_board-0.9.9/lb_private/lang/de/ucp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activated'=>'Konto aktiviert',
'auto_bookmark'=>'Automatische Lesezeichen',
'blacklist_has_been_added'=>'Du hast diesen Benutzer auf deine schwarze Liste gesetzt und ignorierst seine Beiträge.',
'blacklist_has_been_removed'=>'Du hast diesen Benutzer von der schwarzen Liste genommen und seine Beiträge sind nun wieder lesbar.',
'bookmark_has_been_added'=>'Ein Lesezeichen auf diesen Beitrag wurde angelegt.',
'bookmark_has_been_removed'=>'Das Lesezeichen dieses Beitrags wurde entfernt.',
'change_password'=>'Kennwort ändern',
'comment'=>'Benutzerkommentar',
'currently_no_bookmarks'=>'Aktuell sind keine Lesezeichen vorhanden...',
'default_post_license'=>'Standard-Lizenz deiner Beiträge',
'explain_account_active'=>'Falls das Konto deaktiviert wird, kann der Benutzer sich nicht anmelden. Dies kann dazu verwendet werden, um eine Strafe wegen Mißachtung der Regeln auszusprechen.',
'explain_approvement'=>'Sollen neue Beiträge sofort sichtbar sein? Verwende "standard", um die Benutzergruppen-Einstellung zu vererben.',
'explain_auto_bookmark'=>'Sofern <u>aktiviert</u> wird für jedes Thema, das du schreibst, automatisch ein Lesezeichen angelegt.',
'explain_comment'=>'Jeglichen Kommentar, den du hier einträgst, erscheint dem Benutzer nach seinem nächsten Anmelden im Forum und wird nach dessen Abmeldung entfernt.',
'explain_group'=>'Wähle die Benutzergruppe, der dieser Benutzer zugeordnet sein soll.',
'explain_login_annoy'=>'Falls du ein bißchen Ärger machen möchtest während der Benutzer angemeldet ist, kannst du hier Schabernack anschalten. Das kann nützlich sein, um nervige Menschen loszuwerden. Sofern aktiviert, bekommt er gelegentlich eine leere Seite, zufällige Fehlermeldungen oder ein nettes Kaleidoskop zu sehen.',
'explain_login_liberal'=>'Falls du gesagt bekommst, daß sich deine IP-Adresse während der Anmeldung häufig ändert, kannst du diese Einschränkung hier abschalten. Bitte sei vorsichtig, wenn du den "Soft-Login" <u>aktivierst</u>. Üblicherweise ist dies hinter Proxy-Servern nötig oder wenn du ein Anonymisierungsnetz benutzt.',
'explain_password'=>'Bitte benutze ein Kennwort, daß möglichst viele Zeichen enthält. Benutze keine Wörter, die leicht zu erraten sind (wie Name des Kindes oder Geburtsdatum) oder in Wörterbüchern vorkommen. Auch keine Variationen mit hinzugefügter Zahl oder rückwärts geschrieben. Eine gute Möglichkeit ist, einen Satz zu nehmen, den du dir merken kannst und den Anfangsbuchstaben jedes Wortes zu verwenden. Ein Beispiel: "Mein Vater erklärt mir jeden Samstag unsere 9 Planeten" wird zu "MVemjSu9P". Das Kennwort muß wenigstens fünf Zeichen lang, aber nicht mahr als einunddreißig (31) sein.',
'explain_post_license'=>'Du kannst hier die Lizenz auswählen, die für deine zukünftigen Beiträge gilt. Ältere behalten ihre ohne Änderung.',
'explain_style'=>'Du kannst hier das Aussehen und die Sprache des Forums bestimmen. Belasse "--" für den Standard.',
'explain_timezone'=>'Falls du deine Zeitzone korrekt angezeigt bekommen möchtest, wähle hier deine entsprechende aus. Belasse "--" für den Standard.',
'explain_ucp_mail'=>'Bitte gebe hier eine gültige E-Mail Adresse an, damit wir dich gelegentlich über Änderungen in unserem Forum informieren können. Die Adresse wird nicht weitergegeben. Wenn du das nicht möchtest, belasse das Feld leer. Beachte aber, daß du zukünftig dann nicht "Passwort vergessen" benutzen kannst.',
'explain_warning'=>'Falls dieser Benutzer die Nutzungsbedingungen verletzt oder anderweitig für Aufsehen sorgt, kannst du hier seine Warnstufe ändern. Sobald er höhere Stufen erreicht, wird dies im öffentlichen Profil neben den Beiträgen angezeigt. Zusätzlich, wenn die höchste Stufe zugewiesen ist, wird der Benutzer solange darüber informiert, bis die Warnung hier reduziert wird.',
'general_data'=>'Allgemeine Daten',
'login_annoy'=>'Während Anmeldung nerven',
'login_liberal'=>'Soft-Login',
'mail_has_no_mx_dns_record'=>'Deine E-Mail Adresse scheint keinen gültigen Mailserver zu besitzen!',
'mail_not_valid'=>'Deine E-Mail Adresse ist ungültig!',
'must_not_edit_foreign_profile'=>'Du darfst kein fremdes Profil bearbeiten, da dir Verwalterrechte fehlen!',
'my_bookmarks'=>'Meine Lesezeichen',
'my_profile_settings'=>'Meine Profil-Einstellungen',
'new_passwords_not_equal'=>'Deine neuen Kennwörter sind ungleich!',
'new_password_too_short'=>'Dein neues Kennwort erfüllt nicht die Längekriterien!',
'old_password_not_correct'=>'Dein aktuelles Kennwort stimmt nicht!',
'password_again'=>'Bitte wiederholen',
'password_new'=>'Neues Kennwort',
'password_old'=>'Aktuelles Kennwort',
'posting_already_reported'=>'Dieser Beitrag wurde bereits von einem Benutzer gemeldet!',
'posting_approvement'=>'Beitrag-Sichtbarkeit',
'posting_count'=>'Beiträge verfasst',
'posting_report_success'=>'Vielen Dank, daß du uns diesen Beitrag gemeldet hast. Wir werden uns darum kümmern.',
'post_license_msg_ccbynd'=>'Uneingeschränkte Verbreitung erlauben, aber keine Änderungen.',
'post_license_msg_ccbysa'=>'Uneingeschränkte Verbreitung und Änderungen erlauben, solange die Lizenz beibehalten wird.',
'post_license_msg_none'=>'Keine Weiterverwendung mit Ausnahme von Zitaten in unserem Forum',
'profile_successfully_saved'=>'Das Profil wurde gespeichert.',
'show_effective_permission'=>'Effektive Zugriffsrechte anzeigen',
'style'=>'Aussehen',
'timezone'=>'Zeitzone',
'time_format_24h'=>'24-Stunden-Format benutzen',
'warning_foreign_profile'=>'Bitte nehme zu Kenntnis, daß du ein fremdes Profil bearbeitest!'
);
?>

==> larus_board-0.9.16.zip: larus_board-0.9.16/lb_private/lang/de/ucp.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008,2009 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'account_activated'=>'Konto aktiviert',
'auto_bookmark'=>'Automatische Lesezeichen',
'blacklist_has_been_added'=>'Du hast diesen Benutzer auf deine schwarze Liste gesetzt und ignorierst seine Beiträge.',
'blacklist_has_been_removed'=>'Du hast diesen Benutzer von der schwarzen Liste genommen und seine Beiträge sind nun wieder lesbar.',
'bookmark_has_been_added'=>'Ein Lesezeichen auf diesen Beitrag wurde angelegt.',
'bookmark_has_been_removed'=>'Das Lesezeichen dieses Beitrags wurde entfernt.',
'change_password'=>'Kennwort ändern',
'comment'=>'Benutzerkommentar',
'currently_no_bookmarks'=>'Aktuell sind keine Lesezeichen vorhanden...',
'default_post_license'=>'Standard-Lizenz deiner Beiträge',
'delete_user_confirm'=>'Ich möchte den Benutzer wirklich löschen!',
'delete_user_keep_posts'=>'Die Beiträge des Benutzers beibehalten',
'explain_account_active'=>'Falls das Konto deaktiviert wird, kann der Benutzer sich nicht anmelden. Dies kann dazu verwendet werden, um eine Strafe wegen Mißachtung der Regeln auszusprechen.',
'explain_approvement'=>'Sollen neue Beiträge sofort sichtbar sein? Verwende "standard", um die Benutzergruppen-Einstellung zu vererben.',
'explain_auto_bookmark'=>'Sofern <u>aktiviert</u> wird für jedes Thema, das du schreibst, automatisch ein Lesezeichen angelegt.',
'explain_comment'=>'Jeglichen Kommentar, den du hier einträgst, erscheint dem Benutzer nach seinem nächsten Anmelden im Forum und wird nach dessen Abmeldung entfernt.',
'explain_group'=>'Wähle die Benutzergruppe, der dieser Benutzer zugeordnet sein soll.',
'explain_login_annoy'=>'Falls du ein bißchen Ärger machen möchtest während der Benutzer angemeldet ist, kannst du hier Schabernack anschalten. Das kann nützlich sein, um nervige Menschen loszuwerden. Sofern aktiviert, bekommt er gelegentlich eine leere Seite, zufällige Fehlermeldungen oder ein nettes Kaleidoskop zu sehen.',
'explain_login_liberal'=>'Falls du gesagt bekommst, daß sich deine IP-Adresse während der Anmeldung häufig ändert, kannst du diese Einschränkung hier abschalten. Bitte sei vorsichtig, wenn du den "Soft-Login" <u>aktivierst</u>. Üblicherweise ist dies hinter Proxy-Servern nötig oder wenn du ein Anonymisierungsnetz benutzt.',
'explain_password'=>'Bitte benutze ein Kennwort, daß möglichst viele Zeichen enthält. Benutze keine Wörter, die leicht zu erraten sind (wie Name des Kindes oder Geburtsdatum) oder in Wörterbüchern vorkommen. Auch keine Variationen mit hinzugefügter Zahl oder rückwärts geschrieben. Eine gute Möglichkeit ist, einen Satz zu nehmen, den du dir merken kannst und den Anfangsbuchstaben jedes Wortes zu verwenden. Ein Beispiel: "Mein Vater erklärt mir jeden Samstag unsere 9 Planeten" wird zu "MVemjSu9P". Das Kennwort muß wenigstens fünf Zeichen lang, aber nicht mehr als einunddreißig (31) sein.',
'explain_post_license'=>'Du kannst hier die Lizenz auswählen, die für deine zukünftigen Beiträge gilt. Ältere behalten ihre ohne Änderung.',
'explain_style'=>'Du kannst hier das Aussehen und die Sprache des Forums bestimmen. Belasse "--" für den Standard.',
'explain_timezone'=>'Falls du deine Zeitzone korrekt angezeigt bekommen möchtest, wähle hier deine entsprechende aus. Belasse "--" für den Standard.',
'explain_ucp_mail'=>'Bitte gebe hier eine gültige E-Mail Adresse an, damit wir dich gelegentlich über Änderungen in unserem Forum informieren können. Die Adresse wird nicht weitergegeben. Wenn du das nicht möchtest, belasse das Feld leer. Beachte aber, daß du zukünftig dann nicht "Passwort vergessen" benutzen kannst.',
'explain_warning'=>'Falls dieser Benutzer die Nutzungsbedingungen verletzt oder anderweitig für Aufsehen sorgt, kannst du hier seine Warnstufe ändern. Sobald er höhere Stufen erreicht, wird dies im öffentlichen Profil neben den Beiträgen angezeigt. Zusätzlich, wenn die höchste Stufe zugewiesen ist, wird der Benutzer solange darüber informiert, bis die Warnung hier reduziert wird.',
'general_data'=>'Allgemeine Daten',
'last_postings_by_user'=>'Letzte Beiträge des Benutzers',
'login_annoy'=>'Während Anmeldung nerven',
'login_liberal'=>'Soft-Login',
'mail_has_no_mx_dns_record'=>'Deine E-Mail Adresse scheint keinen gültigen Mailserver zu besitzen!',
'mail_not_valid'=>'Deine E-Mail Adresse ist ungültig!',
'must_not_edit_foreign_profile'=>'Du darfst kein fremdes Profil bearbeiten, da dir Verwalterrechte fehlen!',
'my_bookmarks'=>'Meine Lesezeichen',
'my_profile_settings'=>'Meine Profil-Einstellungen',
'new_passwords_not_equal'=>'Deine neuen Kennwörter sind ungleich!',
'new_password_too_short'=>'Dein neues Kennwort erfüllt nicht die Längekriterien!',
'old_password_not_correct'=>'Dein aktuelles Kennwort stimmt nicht!',
'password_again'=>'Bitte wiederholen',
'password_new'=>'Neues Kennwort',
'password_old'=>'Aktuelles Kennwort',
'posting_already_reported'=>'Dieser Beitrag wurde bereits von einem Benutzer gemeldet!',
'posting_approvement'=>'Beitrag-Sichtbarkeit',
'posting_count'=>'Beiträge verfasst',
'posting_report_success'=>'Vielen Dank, daß du uns diesen Beitrag gemeldet hast. Wir werden uns darum kümmern.',
'post_license_msg_ccbynd'=>'Uneingeschränkte Verbreitung erlauben, aber keine Änderungen.',
'post_license_msg_ccbysa'=>'Uneingeschränkte Verbreitung und Änderungen erlauben, solange die Lizenz beibehalten wird.',
'post_license_msg_none'=>'Keine Weiterverwendung mit Ausnahme von Zitaten in unserem Forum',
'profile_successfully_saved'=>'Das Profil wurde gespeichert.',
'show_effective_permission'=>'Effektive Zugriffsrechte anzeigen',
'style'=>'Aussehen',
'timezone'=>'Zeitzone',
'time_format_24h'=>'24-Stunden-Format benutzen',
'visiting_card'=>'Visitenkarte',
'warning_foreign_profile'=>'Bitte nehme zu Kenntnis, daß du ein fremdes Profil bearbeitest!'
);
?>
